.. _api-reference:

API Reference
=============

.. toctree::
   :maxdepth: 1

cooler
------

.. autoclass:: cooler.Cooler
	:members:
.. autofunction:: cooler.get
.. autofunction:: cooler.info
.. autofunction:: cooler.chroms
.. autofunction:: cooler.bins
.. autofunction:: cooler.pixels
.. autofunction:: cooler.matrix
.. autofunction:: cooler.annotate


cooler.io
---------

.. automodule:: cooler.io
	:members:
	:undoc-members:
	:show-inheritance:

cooler.ice
----------
    
.. autofunction:: cooler.ice.iterative_correction


cooler.util
-----------

.. automodule:: cooler.util
    :members:
    :undoc-members:
    :show-inheritance:
